@@ -17,6 +17,7 @@
 use std::convert::TryFrom;
 
 use crate::admin::messages::{self, is_valid_circuit_id};
+use crate::circuit::routing;
 use crate::error::InvalidStateError;
 use crate::protos::admin;
 
@@ -640,3 +641,13 @@ impl From<ProposedCircuit> for Circuit {
         }
     }
 }
+
+impl From<&AuthorizationType> for routing::AuthorizationType {
+    fn from(auth_type: &AuthorizationType) -> Self {
+        match auth_type {
+            AuthorizationType::Trust => routing::AuthorizationType::Trust,
+            #[cfg(feature = "challenge-authorization")]
+            AuthorizationType::Challenge => routing::AuthorizationType::Challenge,
+        }
+    }
+}
