@@ -28,16 +28,17 @@ use super::v0_handlers::{
     AuthorizedHandler, ConnectRequestHandler, ConnectResponseHandler, TrustRequestHandler,
 };
 #[cfg(feature = "challenge-authorization")]
-use super::v1_handlers::{
+use super::v1_handlers::challenge::{
     AuthChallengeNonceRequestHandler, AuthChallengeNonceResponseHandler,
     AuthChallengeSubmitRequestHandler, AuthChallengeSubmitResponseHandler,
 };
+#[cfg(feature = "trust-authorization")]
+use super::v1_handlers::trust::{AuthTrustRequestHandler, AuthTrustResponseHandler};
 #[cfg(any(feature = "trust-authorization", feature = "challenge-authorization"))]
 use super::v1_handlers::{
-    AuthCompleteHandler, AuthProtocolRequestHandler, AuthProtocolResponseHandler,
+    builders::{AuthProtocolRequestHandlerBuilder, AuthProtocolResponseHandlerBuilder},
+    AuthCompleteHandler,
 };
-#[cfg(feature = "trust-authorization")]
-use super::v1_handlers::{AuthTrustRequestHandler, AuthTrustResponseHandler};
 use super::{AuthorizationErrorHandler, AuthorizationMessageHandler};
 
 /// Builder for creating a Dispatcher for Authorization messages
@@ -151,7 +152,16 @@ impl AuthorizationDispatchBuilder {
         })?;
 
         #[cfg(feature = "challenge-authorization")]
-        let signers = self.signers.unwrap_or_default();
+        let signers = self.signers.ok_or_else(|| {
+            InvalidStateError::with_message("Missing required `signers` field".to_string())
+        })?;
+
+        #[cfg(feature = "challenge-authorization")]
+        if signers.is_empty() {
+            return Err(InvalidStateError::with_message(
+                "At least one signer must be configured".to_string(),
+            ));
+        };
 
         #[cfg(feature = "challenge-authorization")]
         let nonce = self.nonce.ok_or_else(|| {
@@ -181,25 +191,35 @@ impl AuthorizationDispatchBuilder {
         // v1 message handlers
         #[cfg(any(feature = "trust-authorization", feature = "challenge-authorization"))]
         {
-            auth_dispatcher.set_handler(Box::new(AuthProtocolRequestHandler::new(
-                auth_manager.clone(),
-                #[cfg(feature = "challenge-authorization")]
-                !signers.is_empty(),
-                #[cfg(feature = "challenge-authorization")]
-                self.expected_authorization.clone(),
-                #[cfg(feature = "challenge-authorization")]
-                self.local_authorization.clone(),
-            )));
+            // allow unused mut, required if challenge-authorization is enabled
+            #![allow(unused_mut)]
+            let mut auth_protocol_request_builder = AuthProtocolRequestHandlerBuilder::default()
+                .with_auth_manager(auth_manager.clone());
 
-            auth_dispatcher.set_handler(Box::new(AuthProtocolResponseHandler::new(
-                auth_manager.clone(),
-                #[cfg(feature = "trust-authorization")]
-                identity,
-                #[cfg(feature = "challenge-authorization")]
-                self.local_authorization.clone(),
-                #[cfg(not(feature = "challenge-authorization"))]
-                None,
-            )));
+            #[cfg(feature = "challenge-authorization")]
+            {
+                auth_protocol_request_builder = auth_protocol_request_builder
+                    .with_expected_authorization(self.expected_authorization.clone())
+                    .with_local_authorization(self.local_authorization.clone())
+            }
+
+            auth_dispatcher.set_handler(Box::new(auth_protocol_request_builder.build()?));
+
+            let mut auth_protocol_response_builder = AuthProtocolResponseHandlerBuilder::default()
+                .with_auth_manager(auth_manager.clone());
+
+            #[cfg(feature = "trust-authorization")]
+            {
+                auth_protocol_response_builder =
+                    auth_protocol_response_builder.with_identity(&identity);
+            }
+            #[cfg(feature = "challenge-authorization")]
+            {
+                auth_protocol_response_builder = auth_protocol_response_builder
+                    .with_required_local_auth(self.local_authorization.clone())
+            }
+
+            auth_dispatcher.set_handler(Box::new(auth_protocol_response_builder.build()?));
 
             auth_dispatcher.set_handler(Box::new(AuthCompleteHandler::new(auth_manager.clone())));
         }
@@ -214,9 +234,8 @@ impl AuthorizationDispatchBuilder {
             )));
         }
 
-        // If no signers are configured do not configure challenge authorization
         #[cfg(feature = "challenge-authorization")]
-        if !signers.is_empty() {
+        {
             auth_dispatcher.set_handler(Box::new(AuthChallengeNonceRequestHandler::new(
                 auth_manager.clone(),
                 nonce.clone(),
